@@ -250,7 +250,7 @@ static void detectFootTerminal(FFTerminalFontResult* terminalFont)
         ffFontInitValues(&terminalFont->font, font.chars, "8");
         return;
     }
-    uint32_t size = equal + strlen("size=");
+    uint32_t size = equal + (uint32_t) strlen("size=");
     uint32_t comma = ffStrbufNextIndexC(&font, size, ',');
     if (comma < font.length)
         font.chars[comma] = '\0';
@@ -454,4 +454,6 @@ void ffDetectTerminalFontPlatform(const FFTerminalResult* terminal, FFTerminalFo
         detectWestonTerminal(terminalFont);
     else if(ffStrbufStartsWithIgnCaseS(&terminal->processName, "terminator"))
         detectTerminator(terminalFont);
+    else if(ffStrbufStartsWithIgnCaseS(&terminal->processName, "sakura"))
+        detectFromConfigFile("sakura/sakura.conf", "font=", terminalFont);;
 }
